@@ -1,4 +1,4 @@
-/* eap.h
+/** @file
  * Extenal definitions for EAP Extensible Authentication Protocol dissection
  * RFC 2284, RFC 3748
  *
@@ -36,10 +36,12 @@ WS_DLL_PUBLIC const value_string eap_code_vals[];
 #define EAP_TYPE_AKA        23
 #define EAP_TYPE_PEAP       25
 #define EAP_TYPE_MSCHAPV2   26
+#define EAP_TYPE_MSAUTH_TLV 33
 #define EAP_TYPE_FAST       43
 #define EAP_TYPE_PAX        46
 #define EAP_TYPE_PSK        47
 #define EAP_TYPE_SAKE       48
+#define EAP_TYPE_IKEV2      49
 #define EAP_TYPE_AKA_PRIME  50
 #define EAP_TYPE_GPSK       51
 #define EAP_TYPE_TEAP       55
@@ -73,6 +75,12 @@ WS_DLL_PUBLIC const value_string eap_aka_subtype_vals[];
 
 WS_DLL_PUBLIC const value_string eap_ms_chap_v2_opcode_vals[];
 
+typedef enum {
+  PROTO_DATA_EAP_DUPLICATE_ID,
+  PROTO_DATA_EAP_FRAME_STATE,
+  PROTO_DATA_EAP_TVB,
+} proto_data_eap;
+
 typedef struct _eap_vendor_context {
   guint32   vendor_type;
   guint32   vendor_id;
